<?php

namespace XenGenTr\ResimliOneCikanKonular\Repository;

use XF\Mvc\Entity\AbstractCollection;
use XF\Mvc\Entity\Repository;

class OneCikan extends Repository
{
	public function findOneCikan()
	{
		return $this->finder('XenGenTr\ResimliOneCikanKonular:OneCikan')
			->with('Thread', true)
			->with('Thread.FirstPost', true)
			->order('onecikan_tarih', 'DESC');
	}
	
	public function fetchOneCikanByThread($thread)
	{
		return $this->finder('XenGenTr\ResimliOneCikanKonular:OneCikan')
			->where('thread_id', $thread->thread_id)
			->fetchOne();
	}
	
	public function parseOneCikanlar($onecikanlar)
	{
		foreach ($onecikanlar AS &$onecikan)
		{
			$onecikan = $this->parseOneCikan($onecikan);
		}
		
		return $onecikanlar;
	}
	
	public function parseOneCikan($onecikan)
	{
		if (empty($onecikan->onecikan_aciklama))
		{
			$onecikan->onecikan_aciklama = $onecikan->Thread->FirstPost->message;
		}
		
		return $onecikan;
	}
	
	public function setOneCikanFromUpload($thread, $upload)
	{
		$upload->requireImage();

		if (!$upload->isValid($errors))
		{
			throw new \XF\PrintableException(reset($errors));
		}
		
		$target = 'data://XenGenTr/xengentr_resimlikonular/'.$thread->thread_id.'.jpg';
		$dimensions = \XF::options()->xgt_onecikankonu_resimboyutu;
		$width = $dimensions['width'];
		$height = $dimensions['height'];
			
		try
		{
			$image = \XF::app()->imageManager->imageFromFile($upload->getTempFile());
			
			$ratio = $width / $height;
			$w = $image->getWidth();
			$h = $image->getHeight();
			
			if ($w / $h > $ratio)
			{
				$image->resizeTo($w * ($height / $h), $height);
			}
			else
			{
				$image->resizeTo($width, $h * ($width / $w));
			}

			$w = $image->getWidth();
			$h = $image->getHeight();
			$offWidth = ($w - $width) / 2;
			$offHeight = ($h - $height) / 2;

			$image->crop($width, $height, $offWidth, $offHeight);
			
			$tempFile = \XF\Util\File::getTempFile();
			if ($tempFile && $image->save($tempFile))
			{
				$output = $tempFile;
			}
			unset($image);
			
			\XF\Util\File::copyFileToAbstractedPath($output, $target);
		}
		catch (Exception $e)
		{
			throw new \XF\PrintableException(\XF::phrase('unexpected_error_occurred'));
		}
	}
}